use axum::response::{IntoResponse, Response};
use snafu::Snafu;

use std::path::PathBuf;

#[derive(Debug, Snafu)]
#[snafu(visibility(pub))]
pub enum Error {
    #[snafu(display("Failed to spawn unix socket at {}", path.display()))]
    SocketCreate {
        path: PathBuf,
        source: std::io::Error,
    },

    #[snafu(display("Failed to spawn a web server"))]
    Server { source: hyper::Error },

    #[snafu(display("{}", source))]
    Yunohost { source: yunohost_api::Error },

    #[snafu(display("{}", source))]
    Session {
        source: crate::state::sessions::SessionError,
    },

    #[snafu(display("Failed to executed tokio task"))]
    TokioTask { source: tokio::task::JoinError },

    #[snafu(display("Failed to set permissions on file {}", path.display()))]
    Permissions {
        path: PathBuf,
        source: std::io::Error,
    },

    #[snafu(display("Failed to set owner on file {}", path.display()))]
    PermissionsChown {
        path: PathBuf,
        source: file_owner::FileOwnerError,
    },

    #[snafu(display("Failed to set group on file {}", path.display()))]
    PermissionsChgrp {
        path: PathBuf,
        source: file_owner::FileOwnerError,
    },

    #[snafu(display("No cookie jar"))]
    Cookie,
}

impl IntoResponse for Error {
    fn into_response(self) -> Response {
        self.to_string().into_response()
    }
}
