use axum::Router;
use axum::extract::connect_info::ConnectInfo;
use snafu::prelude::*;
use tokio::net::UnixListener;

use std::path::Path;

use crate::error::*;
mod utils;
pub use utils::*;

pub async fn serve_socket(path: &Path, app: Router) -> Result<(), Error> {
    let uds = UnixListener::bind(path.clone())
        .context(SocketCreateSnafu { path: path.clone() })?;
    hyper::Server::builder(ServerAccept::new(uds))
        .serve(app.into_make_service_with_connect_info::<UdsConnectInfo>())
        .await.context(ServerSnafu)?;

    Ok(())
}

pub async fn handler(ConnectInfo(info): ConnectInfo<UdsConnectInfo>) -> &'static str {
    println!("new connection from `{:?}`", info);

    "Hello, World!"
}
