use snafu::Snafu;

use std::path::PathBuf;

use crate::Username;

#[derive(Debug, Snafu)]
#[snafu(visibility(pub))]
pub enum Error {
    #[snafu(display("Failed to establish connection to the LDAP database at path {uri}"))]
    LdapInit { uri: String, source: ldap3::result::LdapError },
    
    #[snafu(display("Failed to bind on the LDAP database"))]
    LdapBind { source: ldap3::result::LdapError },

    #[snafu(display("Failed to search the LDAP database"))]
    LdapSearch { source: ldap3::result::LdapError },

    #[snafu(display("No such user: {}", username.as_str()))]
    LdapNoSuchUser { username: Username },

    #[snafu(display("Empty username provided for login"))]
    EmptyUsername,

    #[snafu(display("Empty password provided for login"))]
    EmptyPassword,

    #[snafu(display("Failed to read file {}", path.display()))]
    ReadFile { path: PathBuf, source: std::io::Error },
    
    #[snafu(display("Invalid JSON in file {}", path.display()))]
    InvalidJson { path: PathBuf, source: serde_json::Error },
}
