use std::path::Path;

use crate::error::*;
use crate::JsonCache;

mod ssowat;
pub use ssowat::{SSOWatConfig, PermissionName};

#[derive(Debug)]
pub struct YunohostPermissions {
    ssowat: JsonCache<SSOWatConfig>,
}

impl YunohostPermissions {
    pub fn new() -> Result<YunohostPermissions, Error> {
        Self::from_path("/etc/ssowat/conf.json")
    }

    pub fn from_path<T: AsRef<Path>>(path: T) -> Result<YunohostPermissions, Error> {
        let path = path.as_ref();
        let ssowat: JsonCache<SSOWatConfig> = JsonCache::load(path)?;
        Ok(YunohostPermissions {
            ssowat,
        })
    }

    pub fn ssowat_config(&self) -> Result<SSOWatConfig, Error> {
        self.ssowat.get()
    }
}
